// ===========================================================================
// CONTENT  : ENUM CompareResult
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 15/05/2020
// HISTORY  :
//  15/05/2020  mdu  CREATED
//
// Copyright (c) 2020, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.bif;

import org.pfsw.bif.conversion.IIntegerRepresentation;
import org.pfsw.bif.enums.IEnumType;

/**
 * Defines enums for the results of <code>Comparator.compare(Object, Object)</code>. 
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
public enum CompareResult implements IEnumType, IIntegerRepresentation
{
  //@formatter:off
  LESS(-1),
  EQUAL(0),
  GREATER(1);
  //@formatter:on

  private final Integer intValue;

  /**
   * Returns the enum value that corresponds to the given integer value.
   * That is, LESS for negative, GREATER for positive values and EQUAL for 0.
   */
  public static CompareResult of(int value)
  {
    if (value < 0)
    {
      return LESS;
    }
    if (value > 0)
    {
      return GREATER;
    }
    return EQUAL;
  }

  private CompareResult(int intValue)
  {
    this.intValue = Integer.valueOf(intValue);
  }

  @Override
  public Integer asInteger()
  {
    return intValue;
  }

  @Override
  public String asString()
  {
    return name();
  }

  /**
   * Returns true if this instance represents the 'less' result.
   */
  public boolean isLess()
  {
    return this == LESS;
  }

  /**
   * Returns true if this instance represents the 'equal' result.
   */
  public boolean isEqual()
  {
    return this == EQUAL;
  }

  /**
   * Returns true if this instance represents the 'equal' result.
   */
  public boolean isGreater()
  {
    return this == GREATER;
  }

  @Override
  public String toString()
  {
    return String.format("%s(%s)", getClass().getSimpleName(), name());
  }
}