// ===========================================================================
// CONTENT  : INTERFACE IExtensibleFluentApi
// AUTHOR   : M.Duchrow
// VERSION  : 1.0 - 11/12/2020
// HISTORY  :
//  11/12/2020  mdu  CREATED
//
// Copyright (c) 2020, by Manfred Duchrow. All rights reserved.
// ===========================================================================
package org.pfsw.bif;

/**
 * Implementing this interface allows easy creation of classes with fluent API (like builders)
 * that should allow sub-classing.  
 * <p>
 * Implement the basic functionality into an abstract class (e.g. MyBuilder).
 * 
 * <code>public abstract class MyBuilder<T extends MyBuilder> implements IExtensibleFluentApi<T></code>
 * 
 * with a method 
 * 
 * <code>
 *   {@literal @}SuppressWarnings("unchecked")
 *   {@literal @}Override
 *   public T self()
 *   {
 *     return (T)this;
 *   }
 * </code>
 * 
 * and make the return type of all fluent API methods <strong>T</strong>.
 * 
 */
public interface IExtensibleFluentApi<T>
{
  T self();
}
