// ===========================================================================
// CONTENT  : CLASS IBiConsumer
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 02/08/2021
// HISTORY  :
//  02/08/2021  mdu  CREATED
//
// Copyright (c) 2021, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.bif.callback;

/**
 * Can be used like Java 8 java.util.function.BiConsumer, but is available for Java 6.
 *
 * Represents an operation that accepts two input arguments and returns no result.  
 * This is the two-arity specialization of {@link IConsumer}.
 * Unlike most other functional interfaces, {@code IBiConsumer} is expected to operate via side-effects.
 *
 * @param <T> the type of the first argument to the operation.
 * @param <U> the type of the second argument to the operation.
 */
//@FunctionalInterface
public interface IBiConsumer<T, U>
{
  /**
   * Performs this operation on the given arguments.
   *
   * @param t the first input argument.
   * @param u the second input argument.
   */
  void accept(T t, U u);
}
