// ===========================================================================
// CONTENT  : INTERFACE IPredicate
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 14/02/2020
// HISTORY  :
//  14/02/2020  mdu  CREATED
//
// Copyright (c) 2020, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.bif.callback;

/**
 * Can be used like Java 8 java.util.function.Predicate, but is available for Java 6.
 *
 * Represents a predicate (boolean-valued function) of one argument.
 *
 * <p>This is a <a href="package-summary.html">functional interface</a>
 * whose functional method is {@link #test(Object)}.
 *
 * @param <T> the type of the input to the predicate
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
//@FunctionalInterface
public interface IPredicate<T>
{
  /**
   * Evaluates this predicate on the given argument.
   *
   * @param t the input argument.
   * @return {@code true} if the input argument matches the predicate, otherwise {@code false}
   */
  boolean test(T t);
}