// ===========================================================================
// CONTENT  : INTERFACE IProgressListener
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 28/03/2016
// HISTORY  :
//  28/03/2016  mdu  CREATED
//
// Copyright (c) 2016, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.bif.callback ;

/**
 * A generic interface for listeners of any long-running actions that need to
 * be observable and stoppable.  
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
public interface IProgressListener
{   
  /**
   * This value specifies that the size is undefined or unknown.
   */
  public static final long UNDEFINED_SIZE = Long.MIN_VALUE;

  /**
   * The value returned by a listener that signals to continue processing.
   */
  public static final boolean CONTINUE = true;
  
  /**
   * The value returned by a listener that signals to stop processing.
   */
  public static final boolean STOP = false;
  
  /**
   * Will be called for each arbitrary chunk of work that has been processed.
   * 
   * @param totalSize The total size to be processed for complete execution. If the
   * total size is unknown the {@link #UNDEFINED_SIZE} value must be passed in. 
   * @param processedSize The size that has already been processed.
   * @return true ({@link #CONTINUE}) if processing should continue, false ({@link #STOP}) if processing should stop now.
   */
  public boolean processed(long totalSize, long processedSize);
}