// ===========================================================================
// CONTENT  : INTERFACE IBidirectionalConverter
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 05/03/2017
// HISTORY  :
//  05/03/2017  mdu  CREATED
//
// Copyright (c) 2017, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.bif.conversion ;

/**
 * A general interface for converters that can do conversion from an
 * internal object representation to an external representation and vice versa.
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
public interface IBidirectionalConverter<TInternal, TExternal>
{   
  /**
   * Converts the given external object representation to its
   * corresponding internal representation.
   *  
   * @param object The external representation of the object to convert (may be null).
   * @return null (if given object was null) or the internal representation of the given object.
   * @throws ConversionRuntimeException For any problem that prevented successful object conversion.
   */
  public TInternal toInternal(TExternal object) throws ConversionRuntimeException;

  /**
   * Converts the given internal object representation to its
   * corresponding external representation.
   *  
   * @param object The internal representation of the object to convert (may be null).
   * @return null (if given object was null) or the external representation of the given object.
   * @throws ConversionRuntimeException For any problem that prevented successful object conversion.
   */
  public TExternal toExternal(TInternal object) throws ConversionRuntimeException;
}