// ===========================================================================
// CONTENT  : INTERFACE IEnumType
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 27/12/2018
// HISTORY  :
//  27/12/2018  mdu  CREATED
//
// Copyright (c) 2018, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.bif.enums ;

import org.pfsw.bif.text.IStringRepresentation;

/**
 * A general interface that allows to mark enum types
 * and therefore use the interface rather than the enum directly.
 * That allows to specify multiple enum implementations for the same purpose.
 * <p>
 * The methods declared here are automatically implemented by each enum type because
 * they are implicitly inherited from class java.lang.Enum.
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
public interface IEnumType extends IStringRepresentation
{
  /**
   * Returns the name of this enum constant, exactly as declared in its enum declaration.
   */
  String name();
  
  /**
   * Returns the ordinal of this enumeration constant (its position in its enum declaration, where the initial constant is assigned an ordinal of zero).
   */
  int ordinal();
  
  /**
   * Returns the Class object corresponding to this enum constant's enum type.
   */
  Class<?> getDeclaringClass();
}