// ===========================================================================
// CONTENT  : CLASS NonStandardHttpHeaderName
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 18/12/2020
// HISTORY  :
//  18/12/2020  mdu  CREATED
//
// Copyright (c) 2020, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.bif.http;

/**
 * Definition of header names that are not standard, but used and supported by many user agents and servers.
 */
public enum NonStandardHttpHeaderName implements HttpHeaderName
{
  //@formatter:off
  
  // =========================================================================
  // request and response header name
  // =========================================================================
  X_CORRELATION_ID("X-Correlation-ID"),
  X_REQUEST_ID("X-Request-ID"),

  // =========================================================================
  // request header names
  // =========================================================================
  FRONT_END_HTTPS("Front-End-Https"),
  PROXY_CONNECTION("Proxy-Connection"),
  UPGRADE_UNSECURE_REQUESTS("Upgrade-Insecure-Requests"),
  X_CSRF_TOKEN("X-Csrf-Token"),
  X_FORWARDED_FOR("X-Forwarded-For"),
  X_FORWARDED_HOST("X-Forwarded-Host"),
  X_FORWARDED_PROTOCOL("X-Forwarded-Proto"),
  X_HTTP_METHOD_OVERRIDE("X-Http-Method-Override"),
  X_REQUESTED_WITH("X-Requested-With"),
  
  // =========================================================================
  // response header names
  // =========================================================================
  CONTENT_SECURITY_POLICY("Content-Security-Policy"),
  STATUS("Status"),
  X_CONTENT_DURATION("X-Content-Duration"),
  X_CONTENT_TYPE_OPTIONS("X-Content-Type-Options"),
  X_CONTENT_SECURITY_POLICY("X-Content-Security-Policy"),
  X_FRAME_OPTIONS("X-Frame-Options"),
  X_POWERED_BY("X-Powered-By"),
  X_UA_COMPATIBLE("X-UA-Compatible"),
  X_WEBKIT_CSP("X-WebKit-CSP"),
  X_XSS_PROTECTION("X-XSS-Protection"),
  
  ;
  //@formatter:on
  
  private final String headerName;

  NonStandardHttpHeaderName(String headerName)
  {
    this.headerName = headerName;
  }
  
  @Override
  public boolean isHeaderName(String string)
  {
    return asString().equalsIgnoreCase(string);
  }
  
  @Override
  public String asString()
  {
    return getHeaderName();
  }
  
  @Override
  public String toString()
  {
    return String.format("%s(%s, '%s')", getClass().getSimpleName(), name(), asString());
  }
  
  private String getHeaderName()
  {
    return this.headerName;
  }
}
