// ===========================================================================
// CONTENT  : CLASS OtherHttpHeaderName
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 18/12/2020
// HISTORY  :
//  18/12/2020  mdu  CREATED
//
// Copyright (c) 2020, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.bif.http;

/**
 * Definition of header names that are frequently used, but not standardized or specified in any RFC.
 */
public enum OtherHttpHeaderName implements HttpHeaderName
{
  //@formatter:off
  
  // =========================================================================
  // request and response header name
  // =========================================================================

  // =========================================================================
  // request header names
  // =========================================================================
  X_ACCESS_TOKEN("X-Access-Token"),
  X_AUTH_TOKEN("X-Auth-Token"),
  X_JWT_ASSERTION("X-JWT-Assertion"),
  
  // =========================================================================
  // response header names
  // =========================================================================
  
  ;
  //@formatter:on
  
  private final String headerName;

  OtherHttpHeaderName(String headerName)
  {
    this.headerName = headerName;
  }
  
  @Override
  public boolean isHeaderName(String string)
  {
    return asString().equalsIgnoreCase(string);
  }
  
  @Override
  public String asString()
  {
    return getHeaderName();
  }
  
  @Override
  public String toString()
  {
    return String.format("%s(%s, '%s')", getClass().getSimpleName(), name(), asString());
  }
  
  private String getHeaderName()
  {
    return this.headerName;
  }
}
