// ===========================================================================
// CONTENT  : CLASS StandardHttpHeaderName
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 18/12/2020
// HISTORY  :
//  18/12/2020  mdu  CREATED
//
// Copyright (c) 2020, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.bif.http;

/**
 * Definition of header names that are specified in RFCs (e.g. https://tools.ietf.org/html/rfc7231).
 */
public enum StandardHttpHeaderName implements HttpHeaderName
{
  //@formatter:off
  
  // =========================================================================
  // Standard request and response header name
  // =========================================================================
  CACHE_CONTROL("Cache-Control"),
  CONTENT_ENCODING("Content-Encoding"),
  CONTENT_TYPE("Content-Type"),
  CONTENT_LENGTH("Content-Length"),
  DATE("Date"),
  TRANSFER_ENCODING("Transfer-Encoding"),
  UPGRADE("Upgrade"),
  VIA("Via"),
  WARNING("Warning"),

  // =========================================================================
  // Standard request header names
  // =========================================================================
  ACCEPT("Accept"),
  ACCEPT_LANGUAGE("Accept-Language"),
  ACCEPT_CHARSET("Accept-Charset"),
  ACCEPT_ENCODING("Accept-Encoding"),
  AUTHORIZATION("Authorization"),
  COOKIE("Cookie"),
  EXPECT("Expect"),
  FROM("From"),
  HOST("Host"),
  HTTP2_SETTINGS("HTTP2-Settings"),
  IF_MATCH("If-Match"),
  IF_MODIFIED_SINCE("If-Modified-Since"),
  IF_NONE_MATCH("If-None-Match"),
  IF_RANGE("If-Range"),
  IF_UNMODIFIED_SINCE("If-Unmodified-Since"),
  MAX_FORWARDS("Max-Forwards"),
  ORIGIN("Origin"),
  PRAGMA("Pragma"),
  PROXY_AUTHORIZATION("Proxy-Authorization"),
  RANGE(" Range"),
  REFERER("Referer"),
  TE("TE"),
  USER_AGENT("User-Agent"),
  
  // =========================================================================
  // Standard response header names
  // =========================================================================
  // CORS
  ACCESS_CONTROL_ALLOW_ORIGIN("Access-Control-Allow-Origin"),
  ACCESS_CONTROL_ALLOW_CREDENTIALS("Access-Control-Allow-Credentials"),
  ACCESS_CONTROL_EXPOSE_HEADERS("Access-Control-Expose-Headers"),
  ACCESS_CONTROL_MAX_AGE("Access-Control-Max-Age"),
  ACCESS_CONTROL_ALLOW_METHODS("Access-Control-Allow-Methods"),
  ACCESS_CONTROL_ALLOW_HEADERS("Access-Control-Allow-Headers"),
  
  AGE("Age"),
  ALLOW("Allow"),
  CONNECTION("Connection"),
  CONTENT_LANGUAGE("Content-Language"),
  CONTENT_SECURITY_POLICY("Content-Security-Policy"),
  ETAG("ETag"),
  EXPIRES("Expires"),
  LAST_MODIFIED("Last-Modified"),
  LOCATION("Location"),
  P3P("P3P"),
  PROXY_AUTHENTICATE("Proxy-Authenticate"),
  SET_COOKIE("Set-Cookie"),
  SET_COOKIE2("Set-Cookie2"),
  SERVER("Server"),
  WWW_AUTHENTICATE("WWW-Authenticate"),
  VARY("Vary"),
  
  ;
  //@formatter:on
  
  private final String headerName;

  StandardHttpHeaderName(String headerName)
  {
    this.headerName = headerName;
  }
  
  @Override
  public boolean isHeaderName(String string)
  {
    return asString().equalsIgnoreCase(string);
  }
  
  @Override
  public String asString()
  {
    return getHeaderName();
  }
  
  @Override
  public String toString()
  {
    return String.format("%s(%s, '%s')", getClass().getSimpleName(), name(), asString());
  }
  
  private String getHeaderName()
  {
    return this.headerName;
  }
}
