// ===========================================================================
// CONTENT  : ENUM StandardPriority
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 15/05/2020
// HISTORY  :
//  15/05/2020  mdu  CREATED
//
// Copyright (c) 2020, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.bif.priority;

import org.pfsw.bif.enums.IEnumType;

/**
 * Defines some standard priority values.
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
public enum StandardPriority implements IPriority, IEnumType
{
  //@formatter:off
  LOWEST(0),
  LOW(100000),
  MEDIUM(200000),
  HIGH(300000),
  HIGHEST(Integer.MAX_VALUE);
  //@formatter:on

  private final int value;

  private StandardPriority(int value)
  {
    this.value = value;
  }

  @Override
  public Integer asInteger()
  {
    return getValue();
  }

  /**
   * Returns the name of the enum value.
   */
  @Override
  public String asString()
  {
    return name();
  }

  public int getValue()
  {
    return this.value;
  }

  @Override
  public String toString()
  {
    return String.format("%s(%s, %d)", getClass().getSimpleName(), name(), asInteger());
  }
}