// ===========================================================================
// CONTENT  : CLASS IIndentedTextWriter
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 20/12/2020
// HISTORY  :
//  20/12/2020  mdu  CREATED
//
// Copyright (c) 2020, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.bif.text;

import org.pfsw.bif.IExtensibleFluentApi;

/**
 * A generic interface for writing text with indentation support.
 * 
 * @author M.Duchrow
 */
@SuppressWarnings("rawtypes")
public interface IIndentedTextWriter<T extends IIndentedTextWriter> extends IExtensibleFluentApi<T>
{
  /**
   * Returns the number of spaces for one level of indentation. 
   */
  int getIndentSize();

  /**
   * Sets the number of spaces for one level of indentation.
   * If not set explicitly here, the default 2 is used. 
   */
  T setIndentSize(int indentSize);

  /**
   * Increments the indentation level. That means, that all succeeding 
   * write output will be indented one level more at the beginning of each line.
   */
  T indent();

  /**
   * Decrements the indentation level. That means, that all succeeding 
   * write output will be indented one level less at the beginning of each line.
   */
  T outdent();

  /**
   * Writes all given arguments to the output target.
   * If at the beginning of a new line the indentation will be written first.
   */
  T writeAll(Object... arguments);

  /**
   * Writes all given arguments to the output target and finally appends a new line.
   * If at the beginning of a new line the indentation will be written first.
   */
  T writelnAll(Object... arguments);

  /**
   * Writes the given text. It will be written line by line
   * respecting the current indentation. That is, indentation spaces
   * will be inserted on the beginning of each line.
   */
  T writeText(String text);

  /**
   * Writes the given text. It will be written line by line
   * respecting the current indentation. That is, indentation spaces
   * will be inserted on the beginning of each line.
   * After the last line a new line will be written.
   */
  T writelnText(String text);

}
