// ===========================================================================
// CONTENT  : INTERFACE IJSONConvertible
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.1 - 13/07/2019
// HISTORY  :
//  21/01/2012  mdu  CREATED
//  13/07/2019  mdu   changed -> All StringBuffer types to Appendable
//
// Copyright (c) 2012-2019, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.bif.text;

/**
 * Implementers of this interface are capable of converting themselves into
 * a valid JSON string representation. 
 * <p/>
 * For details about JSON see
 * {@link  <a href="http://www.json.org/" target="blank">JSON Web Site</a>}
 *
 * @author Manfred Duchrow
 * @version 1.1
 */
public interface IJSONConvertible
{
  // =========================================================================
  // CONSTANTS
  // =========================================================================
  public static final String JSON_OBJECT_START = JsonSyntaxElement.OBJECT_START.asString();
  public static final String JSON_OBJECT_END = JsonSyntaxElement.OBJECT_END.asString();
  public static final String JSON_ARRAY_START = JsonSyntaxElement.ARRAY_START.asString();
  public static final String JSON_ARRAY_END = JsonSyntaxElement.ARRAY_END.asString();
  public static final String JSON_ELEMENT_SEPARATOR = JsonSyntaxElement.ELEMENT_SEPARATOR.asString();
  public static final String JSON_PAIR_SEPARATOR = JsonSyntaxElement.PAIR_SEPARATOR.asString();
  public static final String JSON_STRING_DELIMITER = JsonSyntaxElement.STRING_DELIMITER.asString();
  public static final String JSON_LITERAL_NULL = JsonSyntaxElement.LITERAL_NULL.asString();
  public static final String JSON_LITERAL_TRUE = JsonSyntaxElement.LITERAL_TRUE.asString();
  public static final String JSON_LITERAL_FALSE = JsonSyntaxElement.LITERAL_FALSE.asString();
  public static final String JSON_STRING_ESCAPE = JsonSyntaxElement.STRING_ESCAPE.asString();

  // =========================================================================
  // PUBLIC INSTANCE METHODS
  // =========================================================================
  /**
   * The receiver of this method must append its internal state as JSON string
   * representation to the given buffer.
   * 
   * @param output The output target to which to append the JSON string (must not be null).
   */
  public void appendAsJSONString(Appendable output);

  /**
   * The receiver of this method returns its internal state as JSON string
   * representation.
   */
  public String toJSON();

}