// ===========================================================================
// CONTENT  : INTERFACE IStringFilter
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 20/03/2016
// HISTORY  :
//  20/03/2016  mdu  CREATED
//
// Copyright (c) 2016, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.bif.text;

/**
 * A simple interface for abstraction of string matching.
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
public interface IStringFilter
{
  // =========================================================================
  // CONSTANTS
  // =========================================================================
  /**
   * A predefined filter that matches no string at all.
   */
  public static final IStringFilter NONE = new IStringFilter()
  {
    @Override
    public boolean matches(String aString)
    {
      return false;
    }
  };

  /**
   * A predefined filter that matches all strings (but not null).
   */
  public static final IStringFilter ALL = new IStringFilter()
  {
    @Override
    public boolean matches(String aString)
    {
      return aString != null;
    }
  };

  // =========================================================================
  // PUBLIC INSTANCE METHODS
  // =========================================================================
  /**
   * Returns true if the given string matches the filter otherwise false.
   * 
   * @param aString Any string or even null
   */
  public boolean matches(String aString);

}