// ===========================================================================
// CONTENT  : ENUM JsonSyntaxElement
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 13/07/2019
// HISTORY  :
//  13/07/2019  mdu  CREATED
//
// Copyright (c) 2019, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.bif.text;

import org.pfsw.bif.enums.IEnumType;

/**
 * Defines an enumeration value for each JSON syntax element. 
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
public enum JsonSyntaxElement implements IEnumType
{
  OBJECT_START("{"),
  OBJECT_END("}"),
  ARRAY_START("["),
  ARRAY_END("]"),
  ELEMENT_SEPARATOR(","),
  PAIR_SEPARATOR(":"),
  STRING_DELIMITER("\""),
  LITERAL_NULL("null"),
  LITERAL_TRUE("true"),
  LITERAL_FALSE("false"),
  STRING_ESCAPE("\\");
  
  private final String stringRepresentation;

  private JsonSyntaxElement(String stringRepresentation)
  {
    this.stringRepresentation = stringRepresentation;
  }
  
  @Override
  public String asString()
  {
    return this.stringRepresentation;
  }
  
  @Override
  public String toString()
  {
    return String.format("%s('%s')", getClass().getSimpleName(), asString());
  }
}