// ===========================================================================
// CONTENT  : CLASS Name
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 17/12/2020
// HISTORY  :
//  17/12/2020  mdu  CREATED
//
// Copyright (c) 2020, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.bif.text;

import static org.pfsw.bif.BasicUtil.*;

/**
 * The representation of a name which does not allow empty string or any white space character.
 */
public class Name implements IName
{
  private final String name;

  /**
   * Creates a new name instance.
   * 
   * @param name The name value to use (must not be null).
   * @return The new name instance.
   * @throws IllegalArgumentException if the given name is null or empty or contains white space characters.
   */
  public static Name create(String name)
  {
    return new Name(name);
  }

  /**
   * Creates a new name instance.
   * 
   * @param name The name value to use (must not be null).
   * @return The new name instance.
   * @throws IllegalArgumentException if the given name is null or empty or contains white space characters.
   */
  public static Name create(IStringConstant name)
  {
    if (name == null)
    {
      throw new IllegalArgumentException(String.format("The provided name must not be null"));
    }
    return create(name.asString());
  }

  /**
   * Creates a new name instance.
   * 
   * @param name The name value to use (must not be null).
   * @throws IllegalArgumentException if the given string is null or empty or contains white space characters.
   */
  protected Name(String name)
  {
    super();
    if (BU.isNullOrBlank(name) || BU.containsWhitespaceChars(name))
    {
      throw new IllegalArgumentException(String.format("The provided string is no valid name: '%s'", name));
    }
    this.name = name.trim();
  }

  public String getName()
  {
    return this.name;
  }

  @Override
  public String asString()
  {
    return getName();
  }

  @Override
  public String toString()
  {
    return String.format("%s('%s')", getClass().getSimpleName(), asString());
  }
}
