// ===========================================================================
// CONTENT  : CLASS RecursiveFileCopyProcessor
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.1 - 13/09/2015
// HISTORY  :
//  12/01/2014  mdu  CREATED
//  13/09/2015  mdu   bugfix  -> construcTargetFile() / PFL-60
//
// Copyright (c) 2014-2015, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.file;

import java.io.File;

import org.pfsw.text.StringUtil;

/**
 * Copies given files from a specified source folder to a specified target folder
 * preserving the relative sub-directories of the source.
 *
 * @author Manfred Duchrow
 * @version 1.1
 */
public class RecursiveFileCopyProcessor extends FileCopyProcessor
{
  // =========================================================================
  // INSTANCE VARIABLES
  // =========================================================================
  private File sourceFolder;

  // =========================================================================
  // CONSTRUCTORS
  // =========================================================================
  public RecursiveFileCopyProcessor(File sourceFolder, File targetFolder)
  {
    super(targetFolder);
    if (sourceFolder == null)
    {
      throw new IllegalArgumentException("The source folder must not be null!");
    }
    if (!sourceFolder.exists())
    {
      throw new IllegalArgumentException("The source folder " + sourceFolder.getAbsolutePath() + " does not exist!");
    }
    if (!sourceFolder.isDirectory())
    {
      throw new IllegalArgumentException("The specified source " + sourceFolder.getAbsolutePath() + " is no directory!");
    }
    setSourceFolder(sourceFolder);
  }

  // =========================================================================
  // PROTECTED INSTANCE METHODS
  // =========================================================================
  @Override
  protected File construcTargetFile(File file)
  {
    String sourcePath;
    String filePath;
    String relativeFilePath;
    File targetFile;
    File targetDir;

    sourcePath = fileUtil().standardize(getSourceFolder().getAbsolutePath());
    filePath = fileUtil().standardize(file.getAbsolutePath());
    relativeFilePath = str().cutHead(filePath, sourcePath);
    targetFile = new File(getTargetFolder() + relativeFilePath);
    targetDir = targetFile.getParentFile();
    if (!targetDir.exists())
    {
      targetDir.mkdirs();
    }
    return targetFile;
  }

  protected File getSourceFolder()
  {
    return sourceFolder;
  }

  protected void setSourceFolder(File sourceFolder)
  {
    this.sourceFolder = new File(fileUtil().standardize(sourceFolder.getAbsolutePath()));
  }

  protected StringUtil str()
  {
    return StringUtil.current();
  }
}
