// ===========================================================================
// CONTENT  : CLASS WindowsDrive
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 01/11/2015
// HISTORY  :
//  01/11/2015  mdu  CREATED
//
// Copyright (c) 2015, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.file.cfiles ;

/**
 * Represents a single virtual or physical drive in a Windows system.
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
public class WindowsDrive extends AbstractContainer
{
  // =========================================================================
  // CONSTRUCTORS
  // =========================================================================
  /**
   * Create the object for a specific drive letter. 
   * The given letter can be any case, but will be converted to lower case internally.
   *  
   * @param driveLetter The letter for the drive which must be in the range of 'a' to 'z'.
   * @throws IllegalArgumentException If the given string contains less or more than one character
   * or if it is null or if it contains any character that is not allowed as drive letter.
   */
  public WindowsDrive(String driveLetter)
  {
    super(driveLetter.toLowerCase()) ;
    this.internalValidate();
  }

  // =========================================================================
  // PUBLIC INSTANCE METHODS
  // =========================================================================
  @Override
  public void appendNameTo(StringBuilder builder)
  {
    if (this.getName() == null)
    {
      throw new IllegalStateException("Drive letter currently not set!");
    }
    builder.append(this.getName()).append(":");
  }

  // =========================================================================
  // PROTECTED INSTANCE METHODS
  // =========================================================================
  protected void internalValidate() 
  {
    String driveLetter;
    
    driveLetter = this.getName();
    if (driveLetter == null)
    {
      throw new IllegalArgumentException("The drive letter must not be null.");
    }
    if ((driveLetter.length() < 1) || (driveLetter.length() > 1))
    {
      throw new IllegalArgumentException("The drive letter must be exactly one character. Given value: " + driveLetter);      
    }
  }
}
