// ===========================================================================
// CONTENT  : INTERFACE MediaType
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 14/05/2020
// HISTORY  :
//  14/05/2020  mdu  CREATED
//
// Copyright (c) 2020, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.net;

import org.pfsw.bif.text.IStringRepresentation;

/**
 * A common interface for classes that define media types.
 * https://www.iana.org/assignments/media-types/media-types.xhtml
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
public interface MediaType extends IStringRepresentation
{
  String MEDIA_TYPE_WILDCARD = "*";
  String MEDIA_TYPE_SEPARATOR = "/";

  /**
   * Returns the main type (e.g. "text" from "text/html").
   */
  String getType();
  
  /**
   * Returns the sub-type (e.g. "html" from "text/html").
   */
  String getSubType();
}