// ===========================================================================
// CONTENT  : CLASS LexicalHandlerDispatcher
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 04/09/2009
// HISTORY  :
//  04/09/2009  mdu  CREATED
//
// Copyright (c) 2009, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.pax;

import org.xml.sax.SAXException;
import org.xml.sax.ext.LexicalHandler;

/**
 * Forwards all method calls to a delegate LexicalHandler which can be exchanged.
 * That is useful if in fact different LexicalHandler instances are needed
 * during one parsing process.
 * The XMLReader.setProperty( "http://xml.org/sax/properties/lexical-handler", handler )
 * only allows to set the LexicalHandler once.
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
public class LexicalHandlerDispatcher implements LexicalHandler
{
  // =========================================================================
  // INSTANCE VARIABLES
  // =========================================================================
  private LexicalHandler lexicalHandler = null;

  // =========================================================================
  // CONSTRUCTORS
  // =========================================================================
  /**
   * Initialize the new instance with no delegate.
   */
  public LexicalHandlerDispatcher()
  {
    super();
  }

  /**
   * Initialize the new instance with an initial handler to delegate to.
   */
  public LexicalHandlerDispatcher(LexicalHandler handler)
  {
    super();
    setLexicalHandler(handler);
  }

  // =========================================================================
  // PUBLIC INSTANCE METHODS
  // =========================================================================
  public LexicalHandler getLexicalHandler()
  {
    return lexicalHandler;
  }

  public void setLexicalHandler(LexicalHandler newValue)
  {
    lexicalHandler = newValue;
  }

  @Override
  public void comment(char[] ch, int start, int length) throws SAXException
  {
    if (getLexicalHandler() != null)
    {
      getLexicalHandler().comment(ch, start, length);
    }
  }

  @Override
  public void endCDATA() throws SAXException
  {
    if (getLexicalHandler() != null)
    {
      getLexicalHandler().endCDATA();
    }
  }

  @Override
  public void endDTD() throws SAXException
  {
    if (getLexicalHandler() != null)
    {
      getLexicalHandler().endDTD();
    }
  }

  @Override
  public void endEntity(String name) throws SAXException
  {
    if (getLexicalHandler() != null)
    {
      getLexicalHandler().endEntity(name);
    }
  }

  @Override
  public void startCDATA() throws SAXException
  {
    if (getLexicalHandler() != null)
    {
      getLexicalHandler().startCDATA();
    }
  }

  @Override
  public void startDTD(String name, String publicId, String systemId) throws SAXException
  {
    if (getLexicalHandler() != null)
    {
      getLexicalHandler().startDTD(name, publicId, systemId);
    }
  }

  @Override
  public void startEntity(String name) throws SAXException
  {
    if (getLexicalHandler() != null)
    {
      getLexicalHandler().startEntity(name);
    }
  }
}
