// ===========================================================================
// CONTENT  : CLASS LoggerProvider
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.1 - 22/06/2014
// HISTORY  :
//  22/12/2003  duma  CREATED
//  22/06/2014  mdu   changed --> Using now LoggerFactory
//
// Copyright (c) 2003-2014, by Manfred Duchrow. All rights reserved.
// ===========================================================================
package org.pfsw.pax;

import org.pfsw.logging.Logger;
import org.pfsw.logging.LoggerFactoryProvider;
import org.pfsw.logging.nil.NilLogger;

/**
 * This is the central access point for the package's logger.
 * Replacing the logger here means that all classes in this package
 * will use the new logger for further output.
 *
 * @author Manfred Duchrow
 * @version 1.1
 */
public class LoggerProvider
{
  // =========================================================================
  // CONSTANTS
  // =========================================================================
  public static final String LOGGER_NAME = "org.pfsw.pax";

  // =========================================================================
  // CLASS VARIABLES
  // =========================================================================
  private static Logger logger = LoggerFactoryProvider.getLoggerFactory().getLogger(LOGGER_NAME);

  // =========================================================================
  // PUBLIC CLASS METHODS
  // =========================================================================
  /**
   * Returns the current logger used by this component to report
   * errors and exceptions. 
   */
  public static Logger getLogger()
  {
    return logger;
  }

  /**
   * Replace the logger by another one. A value of null installs
   * the prg.pf.logging.NilLogger.
   */
  public static void setLogger(Logger newLogger)
  {
    if (newLogger == null)
    {
      logger = new NilLogger();
    }
    else
    {
      logger = newLogger;
    }
  }

  // =========================================================================
  // CONSTRUCTORS
  // =========================================================================
  /**
   * Initialize the new instance with default values.
   */
  private LoggerProvider()
  {
    super();
  }
}