// ===========================================================================
// CONTENT  : CLASS BasePluginRegistration
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 23/11/2014
// HISTORY  :
//  23/11/2014  mdu  CREATED
//
// Copyright (c) 2014, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.plugin;

import java.util.HashMap;
import java.util.Map;

/**
 * An abstract implementation of the PluginRegistration interface that can be 
 * extended and filled with the relevant data by overriding the {@link #initialize()}
 * method.
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
public abstract class BasePluginRegistration implements PluginRegistration
{
  // =========================================================================
  // INSTANCE VARIABLES
  // =========================================================================
  private final Map<String, Class<?>> registrationMap = new HashMap<String, Class<?>>();

  // =========================================================================
  // CONSTRUCTORS
  // =========================================================================
  public BasePluginRegistration()
  {
    super();
    initialize();
  }

  // =========================================================================
  // PUBLIC INSTANCE METHODS
  // =========================================================================
  @Override
  public Map<String, Class<?>> getClassesToRegister()
  {
    HashMap<String, Class<?>> map;

    // Return a copy
    map = new HashMap<String, Class<?>>(getRegistrationMap());
    return map;
  }

  /**
   * Add an entry to the registration data. If another entry with the same key 
   * exists it will be replaced. 
   */
  public void add(String key, Class<?> type)
  {
    if ((key != null) && (type != null))
    {
      getRegistrationMap().put(key, type);
    }
  }

  /**
   * Will be called from the constructor to fill the internal map with values.
   * This method should be overridden by subclasses.
   */
  public void initialize()
  {
    // Nothing here
  }

  // =========================================================================
  // PROTECTED INSTANCE METHODS
  // =========================================================================
  protected Map<String, Class<?>> getRegistrationMap()
  {
    return registrationMap;
  }

}
