// ===========================================================================
// CONTENT  : CLASS PluginRegistrationLoader
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 11/02/2017
// HISTORY  :
//  11/02/2017  mdu  CREATED
//
// Copyright (c) 2017, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.plugin;

import java.util.ArrayList;
import java.util.List;
import java.util.ServiceLoader;

/**
 * Central internal loader for the {@link PluginRegistration} objects that can be
 * found on the classpath by ServiceLoder mechanism.
 * <p>
 * This class maintains a cache to avoid multiple lookups.
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
final class PluginRegistrationLoader
{
  // =========================================================================
  // CONSTANTS
  // =========================================================================
  private static final PluginUtil PU = PluginUtil.current();
  
  // =========================================================================
  // CLASS VARIABLES
  // =========================================================================
  private static List<PluginRegistration> pluginRegistrations = null;
  
  // =========================================================================
  // CLASS METHODS
  // =========================================================================
  static synchronized List<PluginRegistration> getPlugins(final ClassLoader classLoader)
  {
    List<PluginRegistration> result;

    if (pluginRegistrations == null)
    {
      pluginRegistrations = loadPlugins(classLoader);
    }
    result = new ArrayList<PluginRegistration>(pluginRegistrations);
    return result;
  } 
  
  static synchronized void reset()
  {
    pluginRegistrations = null;
  }

  private static List<PluginRegistration> loadPlugins(final ClassLoader classLoader)
  {
    List<PluginRegistration> result;
    ClassLoader loader; 
    ServiceLoader<PluginRegistration> serviceLoader;
    
    loader = PU.getClassLoader(classLoader);
    
    result = new ArrayList<PluginRegistration>();
    serviceLoader = ServiceLoader.load(PluginRegistration.class, loader);
    for (PluginRegistration registration : serviceLoader)
    {
      result.add(registration);
    }
    return result;
  } 
  
}
