// ===========================================================================
// CONTENT  : ABSTRACT CLASS AbstractAuthenticator
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 12/09/2004
// HISTORY  :
//  12/09/2004  mdu  CREATED
//
// Copyright (c) 2004, by Manfred Duchrow. All rights reserved.
// ===========================================================================
package org.pfsw.security.authentication;

import java.net.InetAddress;
import java.net.PasswordAuthentication;

/**
 * This class implements (nearly) the same methods as java.net.Authenticator.
 * Beyond that it provides public setter methods for all authentication relevant
 * fields. 
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
public abstract class AbstractAuthenticator
{
  // =========================================================================
  // INSTANCE VARIABLES
  // =========================================================================
  private String requestingHost = null;
  private int requestingPort = 0;
  private String requestingPrompt = null;
  private String requestingProtocol = null;
  private String requestingScheme = null;
  private InetAddress requestingSite = null;

  // =========================================================================
  // CONSTRUCTORS
  // =========================================================================
  /**
   * Initialize the new instance with default values.
   */
  public AbstractAuthenticator()
  {
    super();
  }

  // =========================================================================
  // PUBLIC INSTANCE METHODS
  // =========================================================================
  public String getRequestingHost()
  {
    return requestingHost;
  }

  public void setRequestingHost(String newValue)
  {
    requestingHost = newValue;
  }

  public int getRequestingPort()
  {
    return requestingPort;
  }

  public void setRequestingPort(int newValue)
  {
    requestingPort = newValue;
  }

  public String getRequestingPrompt()
  {
    return requestingPrompt;
  }

  public void setRequestingPrompt(String newValue)
  {
    requestingPrompt = newValue;
  }

  public String getRequestingProtocol()
  {
    return requestingProtocol;
  }

  public void setRequestingProtocol(String newValue)
  {
    requestingProtocol = newValue;
  }

  public String getRequestingScheme()
  {
    return requestingScheme;
  }

  public void setRequestingScheme(String newValue)
  {
    requestingScheme = newValue;
  }

  public InetAddress getRequestingSite()
  {
    return requestingSite;
  }

  public void setRequestingSite(InetAddress newValue)
  {
    requestingSite = newValue;
  }

  /**
   * Called when password authorization is needed.  Subclasses should
   * override the default implementation, which returns null.
   * @return The PasswordAuthentication collected from the
   *		user, or null if none is provided.
   */
  public PasswordAuthentication getPasswordAuthentication()
  {
    return null;
  }
}
