// ===========================================================================
// CONTENT  : ENUM CodeChallengeMethod
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 24/04/2020
// HISTORY  :
//  24/04/2020  mdu  CREATED
//
// Copyright (c) 2020, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.security.oauth.pkce;

import org.pfsw.bif.enums.IEnumType;

/**
 * Defines the code challenge methods specified by https://tools.ietf.org/html/rfc7636.
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
public enum CodeChallengeMethod implements IEnumType
{
  //@formatter:off
  PLAIN("plain"), 
  S256("S256");
  //@formatter:on

  private final String specName;

  private CodeChallengeMethod(String specName)
  {
    this.specName = specName;
  }

  @Override
  public String asString()
  {
    return this.specName;
  }

  @Override
  public String toString()
  {
    return String.format("%s(%s, '%s')", getClass().getSimpleName(), name(), asString());
  }
}