// ===========================================================================
// CONTENT  : INTERFACE PKCEGenerator
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 24/04/2020
// HISTORY  :
//  24/04/2020  mdu  CREATED
//
// Copyright (c) 2020, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.security.oauth.pkce;

/**
 * A functional interface for the generation of new random proof key for code exchange
 * according to the specification https://tools.ietf.org/html/rfc7636.
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
public interface PKCEGenerator
{
  /**
   * Generates a new random {@link ProofKeyForCodeExchange}.
   * The mechanism how the random code verifier gets generated and the
   * used code challenge method is up to the implementor of this method.
   */
  ProofKeyForCodeExchange generate();
}