// ===========================================================================
// CONTENT  : CLASS PKCEGeneratorFactory
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 24/04/2020
// HISTORY  :
//  24/04/2020  mdu  CREATED
//
// Copyright (c) 2020, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.security.oauth.pkce;

/**
 * A factory that supports getting a {@link PKCEGenerator} implementation for
 * a given {@link CodeChallengeMethod}.
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
public class PKCEGeneratorFactory
{
  /**
   * Returns a {@link PKCEGenerator} that supports the given {@link CodeChallengeMethod}.
   */
  public static PKCEGenerator getPKCEGenerator(CodeChallengeMethod codeChallengeMethod)
  {
    if (codeChallengeMethod == CodeChallengeMethod.S256)
    {
      return S256PKCEGenerator.instance();
    }
    return PlainPKCEGenerator.instance();
  }

  /**
   * No instances intended.
   */
  private PKCEGeneratorFactory()
  {
    super();
  }
}
