// ===========================================================================
// CONTENT  : CLASS GeneralName
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 02/08/2021
// HISTORY  :
//  02/08/2021  mdu  CREATED
//
// Copyright (c) 2021, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.security.x509;

import org.pfsw.bif.text.IName;

public class GeneralName implements IName
{
  private final X509NameType nameType;
  private final String value;
  
  public static GeneralName create(X509NameType nameType, String value)
  {
    return new GeneralName(nameType, value);
  }
  
  public static GeneralName create(int asn1Tag, String value)
  {
    return create(X509NameType.ofTag(asn1Tag), value);
  }
  
  protected GeneralName(X509NameType nameType, String value)
  {
    super();
    this.nameType = nameType;
    this.value = value;
  }

  @Override
  public String asString()
  {
    return getValue();
  }

  public X509NameType getNameType()
  {
    return this.nameType;
  }

  public String getValue()
  {
    return this.value;
  }

  @Override
  public String toString()
  {
    return String.format("%s(%s: '%s')", getClass().getSimpleName(), getNameType().name(), getValue());
  }
}
