// ===========================================================================
// CONTENT  : CLASS X509NameType
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 02/08/2021
// HISTORY  :
//  02/08/2021  mdu  CREATED
//
// Copyright (c) 2021, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.security.x509;

import org.pfsw.bif.text.IStringConstant;

/**
 * Constants for alternative subject and issuer names.
 * See comment of X509Certificate.getSubjectAlternativeNames().
 * 
 * @author M.Duchrow
 */
public enum X509NameType implements IStringConstant
{
  //@formatter:off
  OTHER_NAME("otherName", 0),
  RFC822_NAME("rfc822Name", 1),
  DNS_NAME("dNSName", 2),
  X400_ADDESS("x400Address", 3),
  DIRECTORY_NAME("directoryName", 4),
  EDI_PARTY_NAME("ediPartyName", 5),
  URI("uniformResourceIdentifier", 6),
  IP_ADDRESS("iPAddress", 7),
  REGISTERED_ID("registeredID", 8)
  ;
  //@formatter:on

  private final String asn1Name;
  private final int tag;

  public static X509NameType ofTag(int asn1Tag)
  {
    for (X509NameType element : values())
    {
      if (element.getTag() == asn1Tag)
      {
        return element;
      }
    }
    return null;
  }

  X509NameType(String asn1Name, int tag)
  {
    this.asn1Name = asn1Name;
    this.tag = tag;
  }

  public String getAsn1Name()
  {
    return this.asn1Name;
  }

  public int getTag()
  {
    return this.tag;
  }

  @Override
  public String asString()
  {
    return getAsn1Name();
  }

  @Override
  public String toString()
  {
    return String.format("%s(%s, '%s')", getClass().getSimpleName(), name(), asString());
  }
}
