package org.pfsw.text;

public class DefaultPlaceholderReplacer extends AbstractPlaceholderReplacer
{
  public static final String PH_START_DELIMITER = "${";
  public static final String PH_END_DELIMITER = "}";
  public static final String ENV_VAR_PREFIX = "env.";

  public static DefaultPlaceholderReplacer create()
  {
    return new DefaultPlaceholderReplacer();
  }

  public DefaultPlaceholderReplacer()
  {
    this(PH_START_DELIMITER, PH_END_DELIMITER);
  }

  public DefaultPlaceholderReplacer(String startDelimiter, String endDelimiter)
  {
    super(startDelimiter, endDelimiter);
  }

  /**
   * Returns either the Java system property value of the given placeHolderName or 
   * the environment variable value if the placeholderName starts with "env.".
   * If the placeholder cannot be resoved the defaultValue will be returned.
   */
  @Override
  protected String getValueOfPlaceholder(String placeholderName, String defaultValue)
  {
    String name;
    String value;

    if (placeholderName.startsWith(getEnvVarPrefix()))
    {
      name = str().suffix(placeholderName, getEnvVarPrefix());
      value = System.getenv(name);
    }
    else
    {
      value = System.getProperty(placeholderName);
    }
    return (value == null) ? defaultValue : value;
  }

  protected String getEnvVarPrefix()
  {
    return ENV_VAR_PREFIX;
  }
}
