// ===========================================================================
// CONTENT  : CLASS UUIDGenerator
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 28/04/2021
// HISTORY  :
//  28/04/2021  mdu  CREATED
//
// Copyright (c) 2021, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.text;

import java.util.UUID;

import org.pfsw.bif.identifier.IObjectIdGenerator;

/**
 * An {@link IObjectIdGenerator} that generates UUIDs.
 */
public class UUIDGenerator implements IObjectIdGenerator
{
  private static final UUIDGenerator DEFAULT_INSTANCE = create();

  /**
   * Returns a newly created instance.
   */
  public static UUIDGenerator create()
  {
    return new UUIDGenerator();
  }

  /**
   * Returns a pre-defined default instance.
   */
  public static UUIDGenerator get()
  {
    return DEFAULT_INSTANCE;
  }

  /**
   * Returns a newly created instance.
   */
  public UUIDGenerator()
  {
    super();
  }

  @Override
  public String newIdentifier()
  {
    return UUID.randomUUID().toString();
  }

  @Override
  public String toString()
  {
    return String.format("%s()", getClass().getSimpleName());
  }
}
