// ===========================================================================
// CONTENT  : INTERFACE JsonConstants
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.1 - 20/03/2016
// HISTORY  :
//  24/08/2014  mdu  CREATED
//  20/03/2016  mdu   change  -> from Charsets to ICharsets
//
// Copyright (c) 2014-2016, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.text.json;

// ===========================================================================
// IMPORTS
// ===========================================================================
import java.nio.charset.Charset;

import org.pfsw.bif.text.ICharsets;
import org.pfsw.bif.text.IJSONConvertible;

/**
 * Fixed values for JSON as constants. 
 * Refers to RFC-7159 (http://tools.ietf.org/html/rfc7159).
 *
 * @author Manfred Duchrow
 * @version 1.1
 */
public interface JsonConstants
{
  public static final Charset DEFAULT_CHARSET = ICharsets.UTF_8;

  public static final char BEGIN_OBJECT = IJSONConvertible.JSON_OBJECT_START.charAt(0);
  public static final char END_OBJECT = IJSONConvertible.JSON_OBJECT_END.charAt(0);

  public static final char BEGIN_ARRAY = IJSONConvertible.JSON_ARRAY_START.charAt(0);
  public static final char END_ARRAY = IJSONConvertible.JSON_ARRAY_END.charAt(0);

  public static final char NAME_SEPARATOR = IJSONConvertible.JSON_PAIR_SEPARATOR.charAt(0);
  public static final char VALUE_SEPARATOR = IJSONConvertible.JSON_ELEMENT_SEPARATOR.charAt(0);

  public static final char STRING_DELIMITER = IJSONConvertible.JSON_STRING_DELIMITER.charAt(0);

  public static final char ESCAPE = IJSONConvertible.JSON_STRING_ESCAPE.charAt(0);

  // Literals
  public static final String FALSE = IJSONConvertible.JSON_LITERAL_FALSE;
  public static final String TRUE = IJSONConvertible.JSON_LITERAL_TRUE;
  public static final String NULL = IJSONConvertible.JSON_LITERAL_NULL;

}