// ===========================================================================
// CONTENT  : CLASS GlobalLocalPlaceholderReplacement
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 01/07/2002
// HISTORY  :
//  01/07/2002  duma  CREATED
//
// Copyright (c) 2002, by Manfred Duchrow. All rights reserved.
// ===========================================================================
package org.pfsw.textx;

/**
 * Contains all variable settings and provides a mechanism, to replace
 * variable names in a text by their current value.
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
public class GlobalLocalPlaceholderReplacement extends GlobalLocalVariables
{
  // =========================================================================
  // INSTANCE VARIABLES
  // =========================================================================
  private TextEngine textEngine;

  // =========================================================================
  // CONSTRUCTORS
  // =========================================================================
  /**
   * Initialize the new instance with default values.
   */
  public GlobalLocalPlaceholderReplacement()
  {
    super();
    setTextEngine(new TextEngine(this));
  }

  // =========================================================================
  // PUBLIC INSTANCE METHODS
  // =========================================================================

  /**
   * Replaces all known variables in the given text and returns the
   * new string.
   */
  public String replace(String text) throws TextReplacementException
  {
    return getTextEngine().completeText(text);
  }

  /**
   * Returns the underlying text engine which might be useful to do further
   * configuration settings.
   */
  public TextEngine getTextEngine()
  {
    return this.textEngine;
  }

  /** 
   * Returns the function resolver 
   */
  public FunctionResolver getFunctionResolver()
  {
    return getTextEngine().getFunctionResolver();
  }

  /** 
   * Sets the function resolver 
   */
  public void setFunctionResolver(FunctionResolver functionResolver)
  {
    getTextEngine().setFunctionResolver(functionResolver);
  }

  // =========================================================================
  // PROTECTED INSTANCE METHODS
  // =========================================================================
  protected void setTextEngine(TextEngine newValue)
  {
    this.textEngine = newValue;
  }
}
