// ===========================================================================
// CONTENT  : ABSTRACT CLASS AbstractBase64Encoder
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 25/04/2020
// HISTORY  :
//  25/04/2020  mdu  CREATED
//
// Copyright (c) 2020, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.util;

import org.pfsw.bif.conversion.IBase64Encoder;

/**
 * Base64 encoding with or without padding.
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
abstract class AbstractBase64Encoder implements IBase64Encoder
{
  private final boolean withPadding;

  protected AbstractBase64Encoder(boolean withPadding)
  {
    super();
    this.withPadding = withPadding;
  }

  @Override
  public String convert(byte[] bytes)
  {
    String encoded;

    encoded = encode(bytes);
    return isWithPadding() ? encoded : stripPadding(encoded);
  }

  protected String stripPadding(String encoded)
  {
    int index = encoded.indexOf('=');
    if (index > 0)
    {
      return encoded.substring(0, index);
    }
    return encoded;
  }

  protected boolean isWithPadding()
  {
    return this.withPadding;
  }

  protected abstract String encode(byte[] bytes);
}
