// ===========================================================================
// CONTENT  : CLASS Base64StandardEncoder
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 25/04/2020
// HISTORY  :
//  25/04/2020  mdu  CREATED
//
// Copyright (c) 2020, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.util;

/**
 * Provides Base64 URL encoding (using '-' and '_') with or without padding (padding char '=').
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
public class Base64UrlEncoder extends AbstractBase64Encoder
{
  /**
   * Creates a new instance of this Base64 encoder with padding.
   */
  public static Base64UrlEncoder withPadding()
  {
    return new Base64UrlEncoder(true);
  }

  /**
   * Creates a new instance of this Base64 encoder without padding.
   */
  public static Base64UrlEncoder withoutPadding()
  {
    return new Base64UrlEncoder(false);
  }
  
  /**
   * Creates a new instance of this Base64 encoder.
   */
  public Base64UrlEncoder(boolean withPadding)
  {
    super(withPadding);
  }

  @Override
  protected String encode(byte[] bytes)
  {
    return Base64Converter.encodeBase64url(bytes);
  }
}
