// ===========================================================================
// wCONTENT  : CLASS EmptyList
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 20/06/2004
// HISTORY  :
//  20/06/2004  mdu  CREATED
//
// Copyright (c) 2004, by Manfred Duchrow. All rights reserved.
// ===========================================================================
package org.pfsw.util;

// ===========================================================================
// IMPORTS
// ===========================================================================
import java.util.ArrayList;
import java.util.Collection;

/**
 * Implements an immutable empty List. That means, no elements can be added 
 * to this list.
 * See Collection.EMPTY_LIST 
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
final class EmptyList<E> extends ArrayList<E>
{
  private static final long serialVersionUID = -74522539872395922L;

  // =========================================================================
  // CONSTRUCTORS
  // =========================================================================
  /**
   * Initialize the new instance with default values.
   */
  EmptyList()
  {
    super(1);
  }

  // =========================================================================
  // PUBLIC INSTANCE METHODS
  // =========================================================================
  @Override
  public void add(int index, E element)
  {
    // Do never add anything
  }

  @Override
  public boolean add(E o)
  {
    // Do never add anything
    return false;
  }

  @Override
  public boolean addAll(Collection<? extends E> c)
  {
    // Do never add anything
    return false;
  }

  @Override
  public boolean addAll(int index, Collection<? extends E> c)
  {
    // Do never add anything
    return false;
  }

  @Override
  public Object clone()
  {
    return this;
  }
}
