// ===========================================================================
// CONTENT  : CLASS EmptyMap
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 20/06/2004
// HISTORY  :
//  20/06/2004  mdu  CREATED
//
// Copyright (c) 2004, by Manfred Duchrow. All rights reserved.
// ===========================================================================
package org.pfsw.util;

// ===========================================================================
// IMPORTS
// ===========================================================================
import java.util.HashMap;
import java.util.Map;

/**
 * Implements an immutable empty Map. That means, no elements can be added 
 * to this map.
 * See Collection.EMPTY_MAP
 *  
 * @author Manfred Duchrow
 * @version 1.0
 */
final class EmptyMap<K, V> extends HashMap<K, V>
{
  private static final long serialVersionUID = -1580493248579589583L;

  // =========================================================================
  // CONSTRUCTORS
  // =========================================================================
  /**
   * Initialize the new instance with default values.
   */
  EmptyMap()
  {
    super();
  }

  // =========================================================================
  // PUBLIC INSTANCE METHODS
  // =========================================================================
  @Override
  public Object clone()
  {
    return this;
  }

  @Override
  public V put(K key, V value)
  {
    // Never add anything
    return null;
  }

  @Override
  public void putAll(Map<? extends K, ? extends V> m)
  {
    // Never add anything
  }
}
