// ===========================================================================
// CONTENT  : CLASS NamedText
// AUTHOR   : Manfred Duchrow
// VERSION  : 2.2 - ß8/09/2019
// HISTORY  :
//  14/07/2002  duma  CREATED
//	11/02/2004	duma	added		-->	copy()
//	16/07/2004	duma	added		-->	copyNamedText()
//	27/03/2010	mdu		changed	-->	to generic type support
//  26/01/2017  mdu   added   --> implements IMutableStringPair
//  08/09/2019  mdu   added   --> of()
//
// Copyright (c) 2002-2019, by Manfred Duchrow. All rights reserved.
// ===========================================================================
package org.pfsw.util;

import org.pfsw.bif.text.IMutableStringPair;

/**
 * An association of a name string and a text value.
 * Both, name and value can never be null!
 * <br>
 * Access to key and value is provided by
 * <ul>
 *   <li>name()
 *   <li>name( newName )
 *   <li>text()
 *   <li>text( newText )
 * </ul>
 *
 * @author Manfred Duchrow
 * @version 2.2
 */
public class NamedText extends NamedValue<String> implements IMutableStringPair
{
  private static final long serialVersionUID = -6457723232212562385L;
  
  // =========================================================================
  // PUBLIC CLASS METHODS
  // =========================================================================
  /**
   * Creates a new instance with a name and an associated text.
   * If name is null it will be transformed to an empty String ("").
   * This is just a convenience factory method.
   */
  public static NamedText of(String name, String text)
  {
    return new NamedText(name, text);
  }

  // =========================================================================
  // CONSTRUCTORS
  // =========================================================================
  /**
   * Initialize the new instance with the given name and value.
   * Both, name and value must not be null. If any of them is null it will
   * be automatically translated to an empty String ("").
   */
  public NamedText(String name, String text)
  {
    super((name == null) ? "" : name, (text == null) ? "" : text);
  }

  // =========================================================================
  // PUBLIC INSTANCE METHODS
  // =========================================================================
  /**
   * Sets the text (value) of the association.
   * 
   * @param newText The new text (a null value will be ignored)
   */
  @Override
  public void value(String newText)
  {
    if (newText != null)
    {
      super.value(newText);
    }
  } 

  /**
   * Sets the text (value) of the association.
   * 
   * @param newText The new text (a null value will be ignored)
   */
  public void text(String newText)
  {
    value(newText);
  }

  /**
   * Returns the text (value) of the association.
   */
  public String text()
  {
    return value();
  }

  /**
   * Returns a copy of this object
   */
  public NamedText copy()
  {
    return copyNamedText();
  }  

  /**
   * Returns a copy of this object
   */
  public NamedText copyNamedText()
  {
    NamedText copy;

    copy = new NamedText(name(), text());
    return copy;
  } 

  @Override
  public String getString1()
  {
    return name();
  }
  
  @Override
  public void setString1(String string)
  {
    name(string);
  }
  
  @Override
  public String getString2()
  {
    return text();
  }
  
  @Override
  public void setString2(String string)
  {
    text(string);
  }
  
  @Override
  public String[] asArray()
  {
    return new String[] { getString1(), getString2() };
  }
  
  @Override
  public String asString(String separator)
  {
    return getString1() + separator + getString2();
  }
} 
