// ===========================================================================
// CONTENT  : CLASS ObjectConverterFunctionAdapter
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 14/02/2020
// HISTORY  :
//  14/02/2020  mdu  CREATED
//
// Copyright (c) 2020, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.util;

import org.pfsw.bif.callback.IFunction;
import org.pfsw.bif.conversion.IObjectConverter;

/**
 * An adapter that maps an {@link IFunction} to the {@link IObjectConverter} interface.
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
public class ObjectConverterFunctionAdapter<T, R> implements IObjectConverter<T, R>
{
  private final IFunction<T, R> function;

  /**
   * Creates a new instance of this adapter. 
   */
  public static <T, R> ObjectConverterFunctionAdapter<T, R> create(IFunction<T, R> function)
  {
    return new ObjectConverterFunctionAdapter<T, R>(function);
  }

  public ObjectConverterFunctionAdapter(IFunction<T, R> function)
  {
    super();
    this.function = function;
  }

  @Override
  public R convert(T source)
  {
    return getFunction().apply(source);
  }

  protected IFunction<T, R> getFunction()
  {
    return this.function;
  }
}
