// ===========================================================================
// CONTENT  : CLASS PrintWriterLineProcessor
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 04/01/2019
// HISTORY  :
//  04/01/2019  mdu  CREATED
//
// Copyright (c) 2019, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.util;

import java.io.Closeable;
import java.io.PrintWriter;

import org.pfsw.bif.text.ILineProcessor;

/**
 * This class maps the {@link ILineProcessor} interface to a {@link PrintWriter}.
 * That is, to the {@link PrintWriter} println(line) method.
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
public class PrintWriterLineProcessor implements ILineProcessor, Closeable
{
  private final PrintWriter printWriter;
  
  public static PrintWriterLineProcessor createStdOutLineProcessor()
  {
    return new PrintWriterLineProcessor(new PrintWriter(System.out));
  }
  
  public PrintWriterLineProcessor(PrintWriter printWriter)
  {
    super();
    if (printWriter == null)
    {
      throw new IllegalArgumentException("printWriter must not be null!");
    }
    this.printWriter = printWriter;
  }

  /**
   * Writes the given line to the underlying printWriter using its println(line) method. 
   */
  @Override
  public boolean processLine(String line, @SuppressWarnings("unused") int lineNo)
  {
    getPrintWriter().println(line);
    return true;
  }
  
  /**
   * Silently closes the underlying printWriter.
   */
  @Override
  public void close()
  {
    IOUtil.current().close(getPrintWriter());
  }
  
  protected PrintWriter getPrintWriter()
  {
    return printWriter;
  }
}
