// ===========================================================================
// CONTENT  : CLASS ProcessExecutionResult
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 04/01/2019
// HISTORY  :
//  04/01/2019  mdu  CREATED
//
// Copyright (c) 2019, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.util;

import java.util.Collections;
import java.util.List;

/**
 * Contains all data from an external process execution.
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
public class ProcessExecutionResult
{
  private final int exitCode;
  private final List<String> outputLines;

  protected ProcessExecutionResult(final int exitCode, final List<String> outputLines)
  {
    super();
    this.exitCode = exitCode;
    this.outputLines = outputLines;
  }
  
  public int getExitCode()
  {
    return this.exitCode;
  }
  
  /**
   * Returns all lines that have been written by the external process to stdout.
   */
  public List<String> getProcessStdOutLines()
  {
    return Collections.unmodifiableList(getOutputLines());
  }
  
  /**
   * Returns the text that the external process has written to stdout.
   */
  public String getProcessStdOutText()
  {
    StringBuffer buffer;
    
    buffer = new StringBuffer();
    for (String line : getOutputLines())
    {
      if (buffer.length() > 0)
      {        
        buffer.append(IOUtil.LINE_SEPARATOR);
      }
      buffer.append(line);
    }
    return buffer.toString();
  }
  
  protected List<String> getOutputLines()
  {
    return this.outputLines;
  }
}
