// ===========================================================================
// CONTENT  : CLASS RandomByteSequenceGenerator
// AUTHOR   : Manfred Duchrow
// VERSION  : 1.0 - 25/04/2020
// HISTORY  :
//  25/04/2020  mdu  CREATED
//
// Copyright (c) 2020, by MDCS. All rights reserved.
// ===========================================================================
package org.pfsw.util;

import org.pfsw.bif.ByteSequenceGenerator;
import org.pfsw.bif.callback.IByteArraySupplier;

/**
 * A generator for random byte arrays of a specific length.
 *
 * @author Manfred Duchrow
 * @version 1.0
 */
public class RandomByteSequenceGenerator implements ByteSequenceGenerator, IByteArraySupplier
{
  /**
   * Creates a new generator for random array with the specified length.
   */
  public static RandomByteSequenceGenerator create(int length)
  {
    return new RandomByteSequenceGenerator(length);
  }

  private final RandomRange randomRange = RandomRange.create(Byte.MIN_VALUE, Byte.MAX_VALUE);
  private final int length;

  /**
   * Creates a new generator for random array with the specified length.
   */
  public RandomByteSequenceGenerator(int length)
  {
    super();
    this.length = length;
  }

  /**
   * Returns a newly generated byte array.
   */
  @Override
  public byte[] getAsByteArray()
  {
    return generateByteSequence();
  }
  
  /**
   * Returns a newly generated byte sequence.
   */
  @Override
  public byte[] generateByteSequence()
  {
    return generateSequence();
  }
  
  @Override
  public String toString()
  {
    return String.format("%s(%d)", getClass().getSimpleName(), getLength());
  }

  protected byte[] generateSequence()
  {
    byte[] byteArray;

    byteArray = new byte[getLength()];
    for (int i = 0; i < byteArray.length; i++)
    {
      byteArray[i] = (byte)getRandomRange().nextInt();
    }
    return byteArray;
  }

  protected RandomRange getRandomRange()
  {
    return this.randomRange;
  }

  protected int getLength()
  {
    return this.length;
  }
}
